==> foxy-proxy-1.35.2.tgz: package/lib/upstream/util.js <==
const JSONbig = require('json-bigint');
const superagent = require('superagent');

function getBestDL(deadlines) {
  return Object.keys(deadlines).reduce((acc, accountId) => {
    const dl = deadlines[accountId];
    if (!acc) {
      return dl;
    }
    if (acc.isGreaterThan(dl)) {
      return dl;
    }

    return acc;
  }, null);
}

async function doBitcoinApiCall(url, method, params = []) {
  const res = await superagent.post(url).unset('User-Agent').send({
    jsonrpc: '2.0',
    id: 0,
    method,
    params,
  });

  return JSONbig.parse(res.res.text).result;
}

async function doBurstApiCall(url, method, params = {}, endpoint = 'burst') {
  const queryParams = {
    requestType: method,
  };
  Object.keys(params).forEach(key => {
    queryParams[key] = params[key];
  });
  const {text: result} = await superagent.get(`${url}/${endpoint}`).query(queryParams).unset('User-Agent');

  return JSON.parse(result);
}

async function getBlockWinnerAccountId(url, isBHD, height, customEndpoint = 'burst') {
  let accountId = await getBlockWinnerAccountIdOrNull(url, isBHD, height, customEndpoint);
  let retries = 0;
  while (accountId === null && retries < 24) {
    await new Promise(resolve => setTimeout(resolve, 5 * 1000));
    accountId = await getBlockWinnerAccountIdOrNull(url, isBHD, height, customEndpoint);
    retries += 1;
  }

  return accountId;
}

async function getBlockWinnerAccountIdOrNull(url, isBHD, height, customEndpoint = 'burst') {
  try {
    if (isBHD) {
        const blockHash = await doBitcoinApiCall(url, 'getblockhash', [height]);
        const block = await doBitcoinApiCall(url, 'getblock', [blockHash], true);

        return block.plotterId.toString();
    } else {
      const block = await doBurstApiCall(url, 'getBlock', {height}, customEndpoint);

      if (!block.generator) {
        return null;
      }

      return block.generator;
    }
  } catch (err) {
    return null;
  }
}

function getTotalMinerCapacity(minersObj) {
  if (!minersObj) {
    return 0;
  }
  const miners = Object.keys(minersObj).map(key => minersObj[key]);

  return miners.reduce((acc, miner) => {
    return acc + (miner.capacity || 0);
  }, 0);
}

module.exports = {
  getBestDL,
  getTotalMinerCapacity,
  getBlockWinnerAccountId,
};

==> foxy-proxy-1.36.1.tgz: package/lib/upstream/util.js <==
const JSONbig = require('json-bigint');
const superagent = require('superagent');

const eventBus = require('../services/event-bus');

function getBestDL(deadlines) {
  return Object.keys(deadlines).reduce((acc, accountId) => {
    const dl = deadlines[accountId];
    if (!acc) {
      return dl;
    }
    if (acc.isGreaterThan(dl)) {
      return dl;
    }

    return acc;
  }, null);
}

async function doBitcoinApiCall(url, method, params = []) {
  const res = await superagent.post(url).unset('User-Agent').send({
    jsonrpc: '2.0',
    id: 0,
    method,
    params,
  });

  return JSONbig.parse(res.res.text).result;
}

async function doBurstApiCall(url, method, params = {}, endpoint = 'burst') {
  const queryParams = {
    requestType: method,
  };
  Object.keys(params).forEach(key => {
    queryParams[key] = params[key];
  });
  const {text: result} = await superagent.get(`${url}/${endpoint}`).query(queryParams).unset('User-Agent');

  return JSON.parse(result);
}

async function getBhdBlockInfo({url, height}) {
  try {
    const blockHash = await doBitcoinApiCall(url, 'getblockhash', [height]);
    const block = await doBitcoinApiCall(url, 'getblock', [blockHash]);
    const plotterId = block.plotterId || block.plotterid;

    return {
      height,
      hash: block.hash,
      plotterId: plotterId.toString(),
    };
  } catch (err) {
    eventBus.publish('log/error', `Failed retrieving block info for height ${height}`);

    return null;
  }
}

async function getBurstBlockInfo({url, height}) {
  try {
    const block = await doBurstApiCall(url, 'getBlock', {height});

    return {
      height,
      hash: block.block,
      plotterId: block.generator,
    };
  } catch (err) {
    eventBus.publish('log/error', `Failed retrieving block info for height ${height}`);

    return null;
  }
}

function getTotalMinerCapacity(minersObj) {
  if (!minersObj) {
    return 0;
  }
  const miners = Object.keys(minersObj).map(key => minersObj[key]);

  return miners.reduce((acc, miner) => {
    return acc + (miner.capacity || 0);
  }, 0);
}

module.exports = {
  getBestDL,
  getTotalMinerCapacity,
  getBhdBlockInfo,
  getBurstBlockInfo,
};
